@@ -34,6 +34,9 @@ from B<File::Stat::Bits>.
 
 require 5.005;
 use strict;
+local $^W=1; # use warnings only since 5.006
+use integer;
+
 use Carp;
 use File::Stat::Bits;
 
@@ -45,7 +48,7 @@ BEGIN
 	@type_to_char %char_to_typemode %ugorw_to_mode %ugox_to_mode
 	@perms_clnid @perms_setid @perms_stick);
 
-    $VERSION = do { my @r = (q$Revision: 0.24 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+    $VERSION = do { my @r = (q$Revision: 0.27 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
     @ISA = ('Exporter');
 
